@@ -14,6 +14,7 @@ import mock
 
 from osc_lib import exceptions
 from osc_lib import utils
+from oslo_utils import uuidutils
 
 from troveclient import common
 from troveclient.osc.v1 import database_instances
@@ -21,44 +22,71 @@ from troveclient.tests.osc.v1 import fakes
 
 
 class TestInstances(fakes.TestDatabasev1):
-    fake_instances = fakes.FakeInstances()
-
     def setUp(self):
         super(TestInstances, self).setUp()
+
+        self.fake_instances = fakes.FakeInstances()
         self.instance_client = self.app.client_manager.database.instances
+        self.mgmt_client = self.app.client_manager.database.mgmt_instances
 
 
 class TestInstanceList(TestInstances):
-
     defaults = {
         'include_clustered': False,
         'limit': None,
         'marker': None
     }
 
-    columns = database_instances.ListDatabaseInstances.columns
-    values = [('1234', 'test-member-1', 'mysql', '5.6', 'ACTIVE', '02', 2,
-              'regionOne'), ('5678', 'test-member-2', 'mysql', '5.6',
-              'ACTIVE', '2', 2, 'regionOne')]
-
     def setUp(self):
         super(TestInstanceList, self).setUp()
         self.cmd = database_instances.ListDatabaseInstances(self.app, None)
         self.data = self.fake_instances.get_instances()
-        self.instance_client.list.return_value = common.Paginated(self.data)
 
     def test_instance_list_defaults(self):
+        self.instance_client.list.return_value = common.Paginated(self.data)
+
         parsed_args = self.check_parser(self.cmd, [], [])
         columns, data = self.cmd.take_action(parsed_args)
+
         self.instance_client.list.assert_called_once_with(**self.defaults)
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.values, data)
+        self.assertEqual(
+            database_instances.ListDatabaseInstances.columns,
+            columns
+        )
+
+        values = [
+            ('1234', 'test-member-1', 'mysql', '5.6', 'ACTIVE', '02', 2,
+             'regionOne'),
+            ('5678', 'test-member-2', 'mysql', '5.6', 'ACTIVE', '2', 2,
+             'regionOne')
+        ]
+        self.assertEqual(values, data)
+
+    def test_instance_list_all_projects(self):
+        self.mgmt_client.list.return_value = common.Paginated(self.data)
+
+        parsed_args = self.check_parser(self.cmd, ["--all-projects"],
+                                        [("all_projects", True)])
+        columns, instances = self.cmd.take_action(parsed_args)
+
+        self.mgmt_client.list.assert_called_once_with(**self.defaults)
+        self.assertEqual(
+            database_instances.ListDatabaseInstances.admin_columns,
+            columns
+        )
+
+        expected_instances = [
+            ('1234', 'test-member-1', 'fake_tenant_id', 'mysql', '5.6',
+             'ACTIVE', '02', 2),
+            ('5678', 'test-member-2', 'fake_tenant_id', 'mysql', '5.6',
+             'ACTIVE', '2', 2)
+        ]
+        self.assertEqual(expected_instances, instances)
 
 
 class TestInstanceShow(TestInstances):
-
     values = ('mysql', '5.6', '02', '1234', '10.0.0.13',
-              'test-member-1', 'regionOne', 'ACTIVE', 2)
+              'test-member-1', 'regionOne', 'ACTIVE', 'fake_tenant_id', 2)
 
     def setUp(self):
         super(TestInstanceShow, self).setUp()
@@ -74,6 +102,7 @@ class TestInstanceShow(TestInstances):
             'name',
             'region',
             'status',
+            'tenant_id',
             'volume',
         )
 
@@ -91,25 +120,44 @@ class TestDatabaseInstanceDelete(TestInstances):
         super(TestDatabaseInstanceDelete, self).setUp()
         self.cmd = database_instances.DeleteDatabaseInstance(self.app, None)
 
-    @mock.patch.object(utils, 'find_resource')
-    def test_instance_delete(self, mock_find):
+    @mock.patch("troveclient.utils.get_resource_id_by_name")
+    def test_instance_delete(self, mock_getid):
+        mock_getid.return_value = "fake_uuid"
+
         args = ['instance1']
-        mock_find.return_value = args[0]
         parsed_args = self.check_parser(self.cmd, args, [])
-        result = self.cmd.take_action(parsed_args)
-        self.instance_client.delete.assert_called_with('instance1')
-        self.assertIsNone(result)
+        self.cmd.take_action(parsed_args)
+
+        mock_getid.assert_called_once_with(self.instance_client, "instance1")
+        self.instance_client.delete.assert_called_with('fake_uuid')
+
+    @mock.patch("troveclient.utils.get_resource_id_by_name")
+    def test_instance_delete_with_exception(self, mock_getid):
+        mock_getid.side_effect = exceptions.CommandError
 
-    @mock.patch.object(utils, 'find_resource')
-    def test_instance_delete_with_exception(self, mock_find):
         args = ['fakeinstance']
         parsed_args = self.check_parser(self.cmd, args, [])
 
-        mock_find.side_effect = exceptions.CommandError
         self.assertRaises(exceptions.CommandError,
                           self.cmd.take_action,
                           parsed_args)
 
+    @mock.patch("troveclient.utils.get_resource_id_by_name")
+    def test_instance_bulk_delete(self, mock_getid):
+        instance_1 = uuidutils.generate_uuid()
+        instance_2 = uuidutils.generate_uuid()
+        mock_getid.return_value = instance_1
+
+        args = ["fake_instance", instance_2]
+        parsed_args = self.check_parser(self.cmd, args, [])
+        self.cmd.take_action(parsed_args)
+
+        mock_getid.assert_called_once_with(self.instance_client,
+                                           "fake_instance")
+
+        calls = [mock.call(instance_1), mock.call(instance_2)]
+        self.instance_client.delete.assert_has_calls(calls)
+
 
 class TestDatabaseInstanceCreate(TestInstances):
 
