@@ -474,7 +474,7 @@ class Instances(base.ManagerWithFind):
                         lines = total_lines
                     part = log_obj_to_display.pop(0)
                     hdrs, log_obj = swift.get_object(container, part['name'])
-                    log_by_lines = log_obj.splitlines()
+                    log_by_lines = log_obj.decode().splitlines()
                     yield "\n".join(log_by_lines[-1 * lines:]) + "\n"
                 else:
                     log_obj_to_display = sorted(
@@ -482,7 +482,7 @@ class Instances(base.ManagerWithFind):
                 for log_part in log_obj_to_display:
                     headers, log_obj = swift.get_object(container,
                                                         log_part['name'])
-                    yield log_obj
+                    yield log_obj.decode()
             except swift_client.ClientException as ex:
                 if ex.http_status == 404:
                     raise exceptions.GuestLogNotFoundError()
